MovementIntConfig

Struct MovementIntConfig 

pub struct MovementIntConfig {
    pub mode: MovementIntMode,
    pub enable: MovementInterrupts,
    pub threshold: u8,
    pub duration: u8,
    pub latch: bool,
    pub only_4d: bool,
    pub high_pass_filter: bool,
}
Movement interrupt configuration

Fields

mode: MovementIntMode

Movement interrupt mode

enable: MovementInterrupts

Interrupts to enable

threshold: u8

Interrupt threshold

duration: u8

Minimum duration of the interrupt event for it to be recognized

latch: bool

Latch interrupt request Cleared by reading movement interrupt source

only_4d: bool

Enable 4D-detection: Disables the Z-axis

high_pass_filter: bool

Enable high-pass filter