pub struct MovementIntConfig {
pub mode: MovementIntMode,
pub enable: MovementInterrupts,
pub threshold: u8,
pub duration: u8,
pub latch: bool,
pub only_4d: bool,
pub high_pass_filter: bool,
}Expand description
Movement interrupt configuration
Fields
mode: MovementIntModeMovement interrupt mode
enable: MovementInterruptsInterrupts to enable
threshold: u8Interrupt threshold
duration: u8Minimum duration of the interrupt event for it to be recognized
latch: boolLatch interrupt request Cleared by reading movement interrupt source
only_4d: boolEnable 4D-detection: Disables the Z-axis
high_pass_filter: boolEnable high-pass filter